@@ -743,7 +743,7 @@ instance Default McpPromptsGetResponseData where
 --
 data McpResourcesTemplatesListResponseResult =
   McpResourcesTemplatesListResponseResult {
-    _resourcesMcpResourcesTemplatesListResponseResult :: RawJsonByteString
+    _resourceTemplatesMcpResourcesTemplatesListResponseResult :: RawJsonByteString
   } deriving (Show, Read, Eq)
 
 $(deriveJSON defaultOptions {fieldLabelModifier = dropDataName "McpResourcesTemplatesListResponseResult", omitNothingFields = True} ''McpResourcesTemplatesListResponseResult)
@@ -751,7 +751,7 @@ makeLenses ''McpResourcesTemplatesListResponseResult
 
 instance Default McpResourcesTemplatesListResponseResult where
   def = McpResourcesTemplatesListResponseResult {
-        _resourcesMcpResourcesTemplatesListResponseResult = def
+        _resourceTemplatesMcpResourcesTemplatesListResponseResult = def
       }
 
 -- |
@@ -1491,9 +1491,9 @@ defaultDomainData = do
   return DomainData {
            _logDirDomainData            = Nothing
          , _logLevelDomainData          = LevelDebug
-         , _toolsDirDomainData          = "./tools"
-         , _promptsDirDomainData        = "./prompts"
-         , _resourcesDirDomainData      = "./resources"
+         , _toolsDirDomainData          = "pty-mcp-server/tools"
+         , _promptsDirDomainData        = "pty-mcp-server/prompts"
+         , _resourcesDirDomainData      = "pty-mcp-server/resources"
          , _requestQueueDomainData      = reqQ
          , _responseQueueDomainData     = resQ
          , _notificationQueueDomainData = notQ
